simulate: Generate Artificial Data for Tests and Illustrations

simulateR Documentation

Generate Artificial Data for Tests and Illustrations

Description

These functions generate two artificial data sets with local dependence of observations.

Usage

simulateNumeric(n, corWithin, corAcross = 0)
simulateBinary(n, corWithin, corAcross = 0)

Arguments

n

Total number of elements in each data set.

corWithin

Correlation of adjacent observations within each data set.

corAcross

Correlation of observations across data sets.

Value

Returns the Cramer's V coefficient.

Note

The simulateNumeric function generates two data sets with elements having standard normal distribution.

The simulateBinary function generates data sets with 0/1 values by thresholding the numeric data sets from simulateNumeric.

The simulatePValues function generates data sets of p-values by applying pnorm to the data sets from simulateNumeric.

Author(s)

Andrey A Shabalin andrey.shabalin@gmail.com

Examples

n = 100000
sim = simulateNumeric(n, 0.5, 0.3)

# Means should be close to 0 (zero)
mean(sim$data1)
mean(sim$data2)

# Variances should be close to 1
var(sim$data1)
var(sim$data2)

# Correlation of adjacent observations
# should be close to 0.5
cor(sim$data1[-1], sim$data1[-n])
cor(sim$data2[-1], sim$data2[-n])

# Correlation between data sets 
# should be close to 0.3
cor(sim$data1, sim$data2)

shiftR documentation built on Sept. 2, 2026, 1:07 a.m.